"""Log templates module for the SecOps Log Hammer package."""

import json
from typing import Dict, Any, List


# Base log templates for different log types
LOG_TEMPLATES: Dict[str, List[Dict[str, Any]]] = {
    "WINEVTLOG": [
        # Windows Event Log - EventID 4624 (Successful Logon)
        json.loads(r"""
        {"EventTime": 1626772730578, "Hostname": "win-test.cbn.local", "Keywords": -9214364837600034816, "EventType": "AUDIT_SUCCESS", "SeverityValue": 2, "Severity": "INFO", "EventID": 4624, "SourceName": "Microsoft-Windows-Security-Auditing", "ProviderGuid": "{54849625-5478-4994-A5BA-3E3B0328C30D}", "Version": 2, "Task": 12544, "OpcodeValue": 0, "RecordNumber": 563207, "ProcessID": 700, "ThreadID": 6616, "Channel": "Security", "Message": "An account was successfully logged on.\r\n\r\nSubject:\r\n\tSecurity ID:\t\th\r\n\tAccount Name:\t\t-\r\n\tAccount Domain:\t\t-\r\n\tLogon ID:\t\t0x0\r\n\r\nLogon Information:\r\n\tLogon Type:\t\t3\r\n\tRestricted Admin Mode:\t-\r\n\tVirtual Account:\t\tNo\r\n\tElevated Token:\t\tYes\r\n\r\nImpersonation Level:\t\tImpersonation\r\n\r\nNew Logon:\r\n\tSecurity ID:\t\tS-1-2-3\r\n\tAccount Name:\t\tUSER\r\n\tAccount Domain:\t\tUSER.LOCAL\r\n\tLogon ID:\t\t0x859278E2\r\n\tLinked Logon ID:\t\t0x0\r\n\tNetwork Account Name:\t-\r\n\tNetwork Account Domain:\t-\r\n\tLogon GUID:\t\t{bbafc98a-da49-6e4f-cdb8-6d07b95ab0a7}\r\n\r\nProcess Information:\r\n\tProcess ID:\t\t0x0\r\n\tProcess Name:\t\t-\r\n\r\nNetwork Information:\r\n\tWorkstation Name:\t-\r\n\tSource Network Address:\t198.51.100.0\r\n\tSource Port:\t\t63359\r\n\r\nDetailed Authentication Information:\r\n\tLogon Process:\t\tKerberos\r\n\tAuthentication Package:\tKerberos\r\n\tTransited Services:\t-\r\n\tPackage Name (NTLM only):\t-\r\n\tKey Length:\t\t0", "Category": "Logon", "Opcode": "Info", "SubjectUserSid": "S-1-2-3", "SubjectUserName": "USER", "SubjectDomainName": "CBN", "SubjectLogonId": "0x0", "TargetUserSid": "S-1-2-3", "TargetUserName": "USER", "TargetDomainName": "USER.LOCAL", "TargetLogonId": "0x859278e2", "LogonType": "3", "LogonProcessName": "Kerberos", "AuthenticationPackageName": "Kerberos", "WorkstationName": "asd", "LogonGuid": "{bbafc98a-da49-6e4f-cdb8-6d07b95ab0a7}", "TransmittedServices": "-", "LmPackageName": "-", "KeyLength": "0", "ProcessName": "-", "IpAddress": "198.51.100.0", "IpPort": "63359", "ImpersonationLevel": "%%1833", "RestrictedAdminMode": "-", "TargetOutboundUserName": "-", "TargetOutboundDomainName": "-", "VirtualAccount": "%%1843", "TargetLinkedLogonId": "0x0", "ElevatedToken": "%%1842", "EventReceivedTime":1629193498, "SourceModuleName": "windows_security_eventlog", "SourceModuleType": "im_msvistalog"}
        """)
    ],
    
    "OKTA": [
        # Okta - user.session.start event
        json.loads(r"""
        {"actor":{"id":"00uttu7unjNbCqQbh1t6","type":"User","alternateId":"andreww@acme.com","displayName":"Andrew User","detailEntry":null},"authenticationContext":{"authenticationProvider":null,"credentialProvider":null,"credentialType":null,"issuer":null,"interface":null,"authenticationStep":0,"externalSessionId":"102Ft93etECSqii8cJPEGooLw"},"displayMessage":"Evaluation of sign-on policy","eventType":"policy.evaluate_sign_on","outcome":{"result":"CHALLENGE","reason":"Sign-on policy evaluation resulted in CHALLENGE"},"published":"2020-04-19T21:28:40.879Z","securityContext":{"asNumber":null,"asOrg":null,"isp":null,"domain":null,"isProxy":null},"severity":"INFO","debugContext":{"debugData":{"requestId":"XfvriI17-NL8irx3E-KQbgAAByw","requestUri":"/api/v1/authn","threatSuspected":"false","url":"/api/v1/authn?"}},"legacyEventType":null,"transaction":{"type":"WEB","id":"XfvriI17-NL8irx3E-KQbgAAByw","detail":{}},"uuid":"86bed42a-22a6-11ea-b224-5743a575edfd","version":"0","request":{"ipChain":[{"ip":"1.2.3.4","geographicalContext":{"city":"Hawthorn","state":"Victoria","country":"Australia","postalCode":"3122","geolocation":{"lat":-37.8199,"lon":145.0285}},"version":"V4","source":null}]},"target":[{"id":"00p2a89ys10b5RgVF1t7","type":"PolicyEntity","alternateId":"unknown","displayName":"MFA - All","detailEntry":{"policyType":"OktaSignOn"}},{"id":"0pr2a8ajrj0EmqOCW1t7","type":"PolicyRule","alternateId":"00p2a89ys10b5RgVF1t7","displayName":"MFA - All offnet","detailEntry":null}]}
        """)
    ],
    
    "AZURE_AD": [
        # Azure AD - Sign-in activity
        json.loads(r"""
        {"time":"2019-09-18T06:52:51.6025883Z","resourceId":"/tenants/fabb61b8-3afe-4e75-b934-a47f782b8cd7/providers/Microsoft.aadiam","operationName":"Sign-in activity","operationVersion":"1.0","category":"SignInLogs","tenantId":"fabb61b8-3afe-4e75-b934-a47f782b8cd7","resultType":"53003","resultSignature":"None","resultDescription":"Access has been blocked due to conditional access policies.","durationMs":0,"callerIpAddress":"1.2.3.4","correlationId":"b805794a-52c1-4401-905c-c20dade8403e","identity":"D***, J****","Level":4,"location":"US","properties":{"SignInBondData":{"LocationDetails":{"Latitude":30.22659,"Longitude":-85.63884,"IPChain":null},"MfaDetails":null,"ConditionalAccessDetails":{"MultiCAEvaluationLog":"0|c04708c3-25ec-4282-aaca-8739084d87e0=4,11,1-3-3-4:2-3-3-4:5-3-3-4:4-3-3-4,1,,,Production-06.14.2018-Block+Basic+Auth+from+External+for+EXO,0,0,0|d814d85b-6be9-4c49-bfb9-a18a9b215f4c=5,11,1-3-3-4:2-4-4,1,,,Production-10.24.2018-Block+ALL+External+Access+to+Service+Ops%2FOff+Shore+per+Lori+Carter+using+Jive_VN5+group,0,0,0|4e72a25f-99d0-4968-b95b-43fe877411bc=5,11,1-3-3-4:2-4-4,,Acme+Terms+of+Use+for+external+access,,Production-10.12.2018+-+LOTO+Exception+Groups+External+Access+TOU+-+All+Platforms+-+All+DEVICES+%26+APPS,0,0,0|bd5d5a3e-5b4e-40df-8830-7d5bd6fb3342=5,11,1-4-4,1,,,Production-04.16.2019-Block+Access+to+Dynamics+CRM+from+External+for+International,0,0,0|9a5a6208-3dbb-4d5f-b53c-f71ea7ea536c=5,11,1-4-4,1,,,Production-05.23.2019-Prevent+External+MFA+registration,0,0,0"},"RamDetails":{"RamRecommendedAction":70,"RamRecommender":6},"DeviceDetails":{"DeviceDisplayName":null,"DeviceId":"","IsCompliant":null,"IsManaged":null,"DeviceTrustType":null},"DisplayDetails":{"UserName":"D***, J****","ApplicationDisplayName":"Office 365 Exchange Online","ProxyRestrictionTargetTenantName":null,"ResourceDisplayName":null,"AttemptedUsername":null},"ProtocolDetails":{"ResponseTime":242,"IsInteractive":null,"AuthenticationMethodsUsed":null,"NetworkLocation":null,"DomainHintPresent":null,"LoginHintPresent":null,"Protocol":null},"PassThroughAuthenticationDetails":null,"IssuerDetails":null,"SourceAlpEvents":null},"id":"2148342a-46f0-4dda-b33c-2af6f4cc1a00","createdDateTime":"2019-09-18T06:52:51.6025883+00:00","userDisplayName":"D***, J****","userPrincipalName":"j****@acme.com","userId":"c952360e-b09a-4331-9351-5b4e4d07ca18","appId":"00000002-0000-0ff1-ce00-000000000000","appDisplayName":"Office 365 Exchange Online","ipAddress":"1.2.3.4","status":{"errorCode":53003,"failureReason":"Access has been blocked due to conditional access policies."},"clientAppUsed":"Other clients; Older Office clients","deviceDetail":{"deviceId":"","operatingSystem":"Windows 7","browser":"Microsoft Office 14.0"},"location":{"city":"Lynn Haven","state":"Florida","countryOrRegion":"US","geoCoordinates":{"latitude":30.22658920288086,"longitude":-85.63883972167969}},"correlationId":"b805794a-52c1-4401-905c-c20dade8403e","conditionalAccessStatus":"failure","appliedConditionalAccessPolicies":[{"id":"c04708c3-25ec-4282-aaca-8739084d87e0","displayName":"Production-06.14.2018-Block Basic Auth from External for EXO","enforcedGrantControls":["Block"],"enforcedSessionControls":[],"result":"failure"}],"originalRequestId":"2148342a-46f0-4dda-b33c-2af6f4cc1a00","isInteractive":false,"tokenIssuerName":"","tokenIssuerType":"AzureAD","authenticationProcessingDetails":[],"networkLocationDetails":[],"processingTimeInMilliseconds":242,"riskDetail":"none","riskLevelAggregated":"none","riskLevelDuringSignIn":"medium","riskState":"none","riskEventTypes":[],"authenticationDetails":[],"authenticationRequirementPolicies":[]},"am_tenantId":"FABB61B8-3AFE-4E75-B934-A47F782B8CD7","am_category":"SIGNINLOGS"}
        """)
    ],
    
    "GCP_CLOUDAUDIT": [
        # GCP Cloud Audit Logs
        json.loads(r"""
        {"insertId":"u0mlpdesys","logName":"projects/base-3-344516/logs/cloudaudit.googleapis.com%2Fdata_access","operation":{"first":true,"id":"10468459370229865006","last":true,"producer":"iamcredentials.googleapis.com"},"protoPayload":{"@type":"type.googleapis.com/google.cloud.audit.AuditLog","authenticationInfo":{"principalEmail":"amosburton@uppercaseresearch0.joonix.net","principalSubject":"user:amosburton@uppercaseresearch0.joonix.net"},"authorizationInfo":[{"authorizationLoggingOptions":{"permissionType":"ADMIN_READ"},"granted":true,"permission":"iam.serviceAccounts.getAccessToken","resourceAttributes":{}}],"metadata":{"identityDelegationChain":["projects/-/serviceAccounts/amosburton-test-impersonation@base-3-344516.iam.gserviceaccount.com"]},"methodName":"GenerateAccessToken","request":{"@type":"type.googleapis.com/google.iam.credentials.v1.GenerateAccessTokenRequest","name":"projects/-/serviceAccounts/amosburton-test-impersonation@base-3-344516.iam.gserviceaccount.com"},"requestMetadata":{"callerIp":"34.173.221.188","callerSuppliedUserAgent":"google-cloud-sdk gcloud/392.0.0 command/gcloud.sql.instances.create invocation-id/a56be32ce8fb4e64bee10d7502542c59 environment/devshell environment-version/None interactive/True from-script/False python/3.9.2 term/screen (Linux 5.10.109+),gzip(gfe)","destinationAttributes":{},"requestAttributes":{"auth":{},"time":"2022-07-22T17:14:10.792366327Z"}},"resourceName":"projects/-/serviceAccounts/110649196922301550006","serviceName":"iamcredentials.googleapis.com","status":{}},"receiveTimestamp":"2022-07-22T17:14:11.386667307Z","resource":{"labels":{"email_id":"amosburton-test-impersonation@base-3-344516.iam.gserviceaccount.com","project_id":"base-3-344516","unique_id":"110649196922301550006"},"type":"service_account"},"severity":"INFO","timestamp":"2022-07-22T17:14:10.782211853Z"}
        """)
    ],
    
    "CS_EDR": [
        # CrowdStrike EDR - ProcessRollup2
        json.loads(r"""
        {"IntegrityLevel":"16384","ParentProcessId":"96415691933129","SourceProcessId":"96415691933129","aip":"198.51.100.1","SHA1HashData":"0000000000000000000000000000000000000000","UserSid":"S-1-5-18","event_platform":"Win","TokenType":"1","ProcessEndTime":"","ParentBaseFileName":"cscript.exe","ImageSubsystem":"2","id":"acbe6864-f201-11ea-953c-069b51868641","EffectiveTransmissionClass":"3","SessionId":"0","Tags":"27, 151, 341, 12094627905582","timestamp":"1599589959527","event_simpleName":"ProcessRollup2","RawProcessId":"9244","ConfigStateHash":"2471234503","MD5HashData":"eaa3ee12b2caa0365f2b4d495b50ad22","SHA256HashData":"f30686dd09b81d4080ab58def209173772fa132fa3762688274270afa6407872","AuthenticationId":"999","ConfigBuild":"1007.3.0011304.1","CommandLine":"\\??\\C:\\Windows\\system32\\conhost.exe 0xffffffff","ParentAuthenticationId":"999","TargetProcessId":"96415693097233","ImageFileName":"\\Device\\HarddiskVolume2\\Windows\\System32\\conhost.exe","SourceThreadId":"392014828599785","Entitlements":"15","name":"ProcessRollup2V17","ProcessStartTime":"1599589959.084","aid":"cc71beda79b940fb4d9223464401c0e4","cid":"558e12bfb64e469e9d86a06e9debcdd8"}
        """)
    ]
} 